==> eiffelstudio-18.11.10.2592.tar: F_code/C10/ir470.c <==
/*
 * Code for class IRON_WORKING_COPY_REPOSITORY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir470.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_WORKING_COPY_REPOSITORY}.make */
void F1031_7955 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1025, 0x00).id, 1025, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1026_7768(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	F1031_7968(Current, loc1);
	tr1 = RTLNS(eif_new_type(1040, 0x00).id, 1040, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F1041_8302(RTCW(tr1), loc1);
	F1031_7956(Current, tr1);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_path */
void F1031_7956 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	tr1 = F1031_7969(Current, arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F536_5163(Current);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_uri */
void F1031_7957 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNS(eif_new_type(1282, 0x00).id, 1282, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1283_12153(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = RTLNS(eif_new_type(1282, 0x00).id, 1282, _OBJSIZ_7_3_0_1_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	F1283_12154(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
	tb1 = F1019_7563(RTCW(tr1), (EIF_CHARACTER_8) '$');
	if (tb1) {
		tr1 = RTLNS(eif_new_type(1025, 0x00).id, 1025, _OBJSIZ_1_1_0_3_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F1041_8341(RTCW(tr2));
		F1024_7697(RTCW(tr1), tr2);
		loc2 = (EIF_REFERENCE) tr1;
		F1031_7968(Current, loc2);
		tr1 = RTLNSMART(eif_new_type(1040, 0).id);
		F1041_8302(RTCW(tr1), loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1282, 0x00).id, 1282, _OBJSIZ_7_3_0_1_0_0_0_0_);
		F1283_12153(RTCW(tr1), arg1);
		loc1 = (EIF_REFERENCE) tr1;
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	F536_5163(Current);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.create_available_packages */
void F1031_7958 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_final_id(Y4693,Y4693_gen_type,Dftype(Current),535).id);
	F859_6094(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.path */
EIF_REFERENCE F1031_7959 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.location */
EIF_REFERENCE F1031_7960 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.available_packages */
EIF_REFERENCE F1031_7962 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IRON_WORKING_COPY_REPOSITORY}.is_same_repository */
EIF_BOOLEAN F1031_7963 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTGC;
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(1030, 0x00),loc1);
	if (EIF_TEST(loc1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F1041_8323(RTCW(tr1));
		tr1 = F1041_8341(RTCW(tr1));
		tr2 = *(EIF_REFERENCE *)(loc1 + _REFACS_1_);
		tr2 = F1041_8323(RTCW(tr2));
		tr2 = F1041_8341(RTCW(tr2));
		Result = F1024_7721(RTCW(tr1), tr2);
	}
	RTLE;
	return Result;
}

/* {IRON_WORKING_COPY_REPOSITORY}.expand_variables */
void F1031_7968 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	struct eif_ex_9 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	RTCFDT;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(10, 0x00).id);
	RTLI(7);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,964,383,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNTS(typres0.id, 2, 0);
	}
	tr2 = RTOSCF(4749,F388_4749,(Current));
	((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
	RTAR(tr1,tr2);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {1011,0xFFF9,1,964,1015,1025,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A323_40_2, (EIF_POINTER) _A323_40_2, (EIF_POINTER)(F384_4695),tr1, 1, 1);
	}
	F11_124(RTCW(loc1), arg1, tr4);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.uri_location_from_path */
EIF_REFERENCE F1031_7969 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1282, 0x00).id, 1282, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1283_12154(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTLE;
	return (EIF_REFERENCE) loc1;
}

void EIF_Minit470 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C10/ir470.c <==
/*
 * Code for class IRON_WORKING_COPY_REPOSITORY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir470.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_WORKING_COPY_REPOSITORY}.make */
void F1031_7932 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1027_7791(RTCW(loc1), arg1);
	F1031_7945(Current, loc1);
	tr1 = RTLNS(eif_new_type(1041, 0x00).id, 1041, _OBJSIZ_2_1_0_0_0_0_0_0_);
	F1042_8352(RTCW(tr1), loc1);
	F1031_7933(Current, tr1);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_path */
void F1031_7933 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	tr1 = F1031_7946(Current, arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	F537_5171(Current);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.make_from_uri */
void F1031_7934 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	loc1 = RTLNS(eif_new_type(1288, 0x00).id, 1288, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1289_12231(RTCW(loc1), arg1);
	tr1 = RTLNS(eif_new_type(1288, 0x00).id, 1288, _OBJSIZ_7_3_0_1_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	F1289_12232(RTCW(tr1), tr2);
	loc1 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
	tb1 = F1019_7552(RTCW(tr1), (EIF_CHARACTER_8) '$');
	if (tb1) {
		loc2 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F1042_8391(RTCW(tr1));
		F1025_7720(RTCW(loc2), tr1);
		F1031_7945(Current, loc2);
		tr1 = RTLNSMART(eif_new_type(1041, 0).id);
		F1042_8352(RTCW(tr1), loc2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	} else {
		loc1 = RTLNS(eif_new_type(1288, 0x00).id, 1288, _OBJSIZ_7_3_0_1_0_0_0_0_);
		F1289_12231(RTCW(loc1), arg1);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_6_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	}
	F537_5171(Current);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.create_available_packages */
void F1031_7935 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_final_id(Y4699,Y4699_gen_type,Dftype(Current),536).id);
	F860_6107(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.location */
EIF_REFERENCE F1031_7937 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IRON_WORKING_COPY_REPOSITORY}.is_same_repository */
EIF_BOOLEAN F1031_7940 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTGC;
	loc1 = arg1;
	loc1 = RTRV(eif_new_type(1030, 0x00),loc1);
	if (EIF_TEST(loc1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F1042_8373(RTCW(tr1));
		tr1 = F1042_8391(RTCW(tr1));
		tr2 = *(EIF_REFERENCE *)(loc1 + _REFACS_1_);
		tr2 = F1042_8373(RTCW(tr2));
		tr2 = F1042_8391(RTCW(tr2));
		Result = F1025_7744(RTCW(tr1), tr2);
	}
	RTLE;
	return Result;
}

/* {IRON_WORKING_COPY_REPOSITORY}.expand_variables */
void F1031_7945 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	struct eif_ex_8 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	RTCFDT;
	RTLD;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(9, 0x00).id);
	RTLI(7);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,965,384,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNTS(typres0.id, 2, 0);
	}
	tr2 = RTOSCF(4757,F389_4757, (Current));
	((EIF_TYPED_VALUE *)tr1+1)->it_r = tr2;
	RTAR(tr1,tr2);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {1012,0xFFF9,1,965,1016,1026,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4= RTLNRF(typres0.id, (EIF_POINTER) __A324_40_2, (EIF_POINTER) _A324_40_2, (EIF_POINTER)(F385_4701),tr1, 1, 1);
	}
	F10_110(RTCW(loc1), arg1, tr4);
	RTLE;
}

/* {IRON_WORKING_COPY_REPOSITORY}.uri_location_from_path */
EIF_REFERENCE F1031_7946 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(1288, 0x00).id, 1288, _OBJSIZ_7_3_0_1_0_0_0_0_);
	F1289_12232(RTCW(loc1), arg1);
	RTLE;
	return (EIF_REFERENCE) loc1;
}

void EIF_Minit470 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
